#ifndef NT2_INCLUDE_FUNCTIONS_DIGAMMA_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DIGAMMA_HPP_INCLUDED

#include <nt2/euler/include/functions/digamma.hpp>

#endif
